A formal S4 class representation of classical Cramer-Lundberg model.
initial_capitala length one numeric non-negative vector specifying an initial capital.
premium_ratea length one numeric non-negative vector specifying a premium rate.
claim_poisson_arrival_ratea length one numeric positive vector specifying the rate of the Poisson process of claims' arrivals.
claim_size_generatora function indicating the random generator of claims' sizes.
claim_size_parametersa named list containing parameters for the random generator of claims' sizes.
The model is defined as follows:
$$X(t) = u + ct - \sum_{i=1}^{N(t)} Y_i,$$
where \(u\) is the initial capital (initial_capital), \(c\) is the
premium rate (premium_rate), \(N(t)\) is the Poisson process with
intensity \(\lambda\) (claim_poisson_arrival_rate), \(Y_i\) are
iid claim sizes (claim_size_generator and claim_size_parameters
).
Objects of class can be created only by using the constructor
CramerLundberg.
Albrecher H., Asmussen A. Ruin Probabilities. World Scientific, 2010.