Learn R Programming

ruin (version 0.1.1)

SparreAndersen: Constructs an object of SparreAndersen S4 class

Description

SparreAndersen() constructs an object of SparreAndersen S4 class.

Usage

SparreAndersen(initial_capital = NULL, premium_rate = NULL,
  claim_interarrival_generator = NULL, claim_interarrival_parameters = NULL,
  claim_size_generator = NULL, claim_size_parameters = NULL)

Arguments

initial_capital

a length one numeric non-negative vector specifying an initial capital. Default: 0.

premium_rate

a length one numeric non-negative vector specifying a premium rate. Default: 1.

claim_interarrival_generator

a function indicating the random generator of claims' interarrival times. Default: rexp.

claim_interarrival_parameters

a named list containing parameters for the random generator of claims' interarrival times. Default: list(rate = 1).

claim_size_generator

a function indicating the random generator of claims' sizes. Default: rexp.

claim_size_parameters

a named list containing parameters for the random generator of claims' sizes. Default: list(rate = 1).

Value

An object of '>SparreAndersen class.

Details

The function constructs an object of a formal S4 class SparreAndersen, a representation of an extension of Cramer-Lundberg model that allows for non-exponential interarrival times and defined as follows: $$X(t) = u + ct - \sum_{i=1}^{N(t)} Y_i,$$ where \(u\) is the initial capital (initial_capital), \(c\) is the premium rate (premium_rate), \(N(t)\) is the renewal process defined by distribution of interarrival times (claim_interarrival_generator and claim_interarrival_parameters), \(Y_i\) are iid claim sizes (claim_size_generator and claim_size_parameters).

References

  • Andersen, E. Sparre. On the collective theory of risk in case of contagion between claims. Transactions of the XVth International Congress of Actuaries, 2(6), 1957.

  • Thorin O. Some Comments on the Sparre Andersen Model in the Risk Theory. ASTIN Bulletin: The Journal of the IAA, 8(1):104-125, 1974.

See Also

CramerLundberg, CramerLundbergCapitalInjections, link{SparreAndersenCapitalInjections}.

Examples

Run this code
# NOT RUN {
model <- SparreAndersen(
  initial_capital = 10,
  premium_rate = 1,
  claim_interarrival_generator = rexp,
  claim_interarrival_parameters = list(rate = 1),
  claim_size_generator = rexp,
  claim_size_parameters = list(rate = 1)
)

# }

Run the code above in your browser using DataLab