Learn R Programming

ruin (version 0.1.1)

SparreAndersen-class: A formal S4 class SparreAndersen

Description

A formal S4 class representation of classical Sparre Andersen model.

Arguments

Slots

initial_capital

a length one numeric non-negative vector specifying an initial capital.

premium_rate

a length one numeric non-negative vector specifying a premium rate.

claim_interarrival_generator

a function indicating the random generator of claims' interarrival times.

claim_interarrival_parameters

a named list containing parameters for the random generator of claims' interarrival times.

claim_size_generator

a function indicating the random generator of claims' sizes.

claim_size_parameters

a named list containing parameters for the random generator of claims' sizes.

Details

The model is defined as follows: $$X(t) = u + ct - \sum_{i=1}^{N(t)} Y_i,$$ where \(u\) is the initial capital (initial_capital), \(c\) is the premium rate (premium_rate), \(N(t)\) is the renewal process defined by distribution of interarrival times (claim_interarrival_generator and claim_interarrival_parameters), \(Y_i\) are iid claim sizes (claim_size_generator and claim_size_parameters).

Objects of class can be created only by using the constructor SparreAndersen.

References

  • Andersen, E. Sparre. On the collective theory of risk in case of contagion between claims. Transactions of the XVth International Congress of Actuaries, 2(6), 1957.

  • Thorin O. Some Comments on the Sparre Andersen Model in the Risk Theory. ASTIN Bulletin: The Journal of the IAA, 8(1):104-125, 1974.

See Also

SparreAndersen